package com.basic.eyflutter_uikit.subscribe;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;

import com.basic.eyflutter_core.channel.OnDistributionSubscribe;
import com.cloud.eyutils.utils.ConvertUtils;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.Binarizer;
import com.google.zxing.BinaryBitmap;
import com.google.zxing.DecodeHintType;
import com.google.zxing.LuminanceSource;
import com.google.zxing.MultiFormatReader;
import com.google.zxing.NotFoundException;
import com.google.zxing.RGBLuminanceSource;
import com.google.zxing.common.GlobalHistogramBinarizer;
import com.google.zxing.common.HybridBinarizer;

import java.util.ArrayList;
import java.util.EnumMap;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.flutter.plugin.common.MethodChannel;

public class RecognitionQrcodeSubscribe extends OnDistributionSubscribe {
    @Override
    public void onSubscribe(MethodChannel.Result result, HashMap<String, Object> arguments) {
        String imagePath = ConvertUtils.toString(arguments.get("imagePath"));
        Bitmap bitmap = BitmapFactory.decodeFile(imagePath);
        if (bitmap == null) {
            result.success("");
            return;
        }
        String data = decodeImage(bitmap);
        result.success(data);
    }

    private String decodeImage(Bitmap bitmap) {
        int width = bitmap.getWidth();
        int height = bitmap.getHeight();
        int[] pixels = new int[width * height];
        bitmap.getPixels(pixels, 0, width, 0, 0, width, height);
        LuminanceSource source = new RGBLuminanceSource(width, height, pixels);
        Binarizer binarizer = new HybridBinarizer(source);
        BinaryBitmap binaryBitmap = new BinaryBitmap(binarizer);
        Map<DecodeHintType, Object> HINTS = new EnumMap<>(DecodeHintType.class);
        try {
            List<BarcodeFormat> allFormats = new ArrayList<>();
            allFormats.add(BarcodeFormat.AZTEC);
            allFormats.add(BarcodeFormat.CODABAR);
            allFormats.add(BarcodeFormat.CODE_39);
            allFormats.add(BarcodeFormat.CODE_93);
            allFormats.add(BarcodeFormat.CODE_128);
            allFormats.add(BarcodeFormat.DATA_MATRIX);
            allFormats.add(BarcodeFormat.EAN_8);
            allFormats.add(BarcodeFormat.EAN_13);
            allFormats.add(BarcodeFormat.ITF);
            allFormats.add(BarcodeFormat.MAXICODE);
            allFormats.add(BarcodeFormat.PDF_417);
            allFormats.add(BarcodeFormat.QR_CODE);
            allFormats.add(BarcodeFormat.RSS_14);
            allFormats.add(BarcodeFormat.RSS_EXPANDED);
            allFormats.add(BarcodeFormat.UPC_A);
            allFormats.add(BarcodeFormat.UPC_E);
            allFormats.add(BarcodeFormat.UPC_EAN_EXTENSION);
            HINTS.put(DecodeHintType.TRY_HARDER, BarcodeFormat.QR_CODE);
            HINTS.put(DecodeHintType.POSSIBLE_FORMATS, allFormats);
            HINTS.put(DecodeHintType.CHARACTER_SET, "utf-8");
            com.google.zxing.Result res = new MultiFormatReader().decode(binaryBitmap, HINTS);
            return res.getText();
        } catch (NotFoundException e) {
            try {
                com.google.zxing.Result res = new MultiFormatReader().decode(new BinaryBitmap(new GlobalHistogramBinarizer(source)), HINTS);
                return res.getText();
            } catch (NotFoundException e1) {
                return "";
            }
        }
    }
}
