import 'dart:io';

import 'package:eyflutter_core/eyflutter_core.dart';
import 'package:eyflutter_uikit/eyflutter_uikit.dart';

class AndroidPermission {
  /// 读取外部存储
  static String get readExternalStorage => "android.permission.READ_EXTERNAL_STORAGE";

  /// 写入外部存储
  static String get writeExternalStorage => "android.permission.WRITE_EXTERNAL_STORAGE";

  /// 媒体
  static String get accessMediaLocation => "android.permission.ACCESS_MEDIA_LOCATION";

  /// 相机
  static String get camera => "android.permission.CAMERA";

  /// 视频录制需要语音采集权限
  static String get recordAudio => "android.permission.RECORD_AUDIO";

  /// 获取设备信息权限
  static String get readPhoneState => "android.permission.READ_PHONE_STATE";
}

// iOS权限
class IOSPermission {
  /// 使用相机
  static String get cameraUse => "hasVideoAuthorization";

  /// 使用相册
  static String get photoLibraryUse => "hasPhotoAuthorization";

  /// 使用麦克风
  static String get microphoneUse => "hasAudioAuthorization";

  /// 使用定位
  static String get locationUse => "hasLocationAuthorization";

  /// 推送通知
  static String get userNotification => "hasUserNotificationAuthorization";

  /// 获取设备信息
  static String get deviceInfoUse => "hasDeviceInfo";
}

class PickerPermissionConfig {
  PickerPermissionConfig._();

  static PickersPermission getPermission() {
    return PickersPermission(
      picker: PermissionItem(
          prompt: "需要访问你图片库权限",
          permissions: Platform.isAndroid
              ? [AndroidPermission.writeExternalStorage, AndroidPermission.readExternalStorage]
              : [IOSPermission.photoLibraryUse]),
      camera: PermissionItem(
          prompt: "需要访问你摄像头权限",
          permissions: Platform.isAndroid
              ? [
                  AndroidPermission.writeExternalStorage,
                  AndroidPermission.readExternalStorage,
                  AndroidPermission.camera,
                  AndroidPermission.recordAudio
                ]
              : [IOSPermission.photoLibraryUse, IOSPermission.cameraUse, IOSPermission.microphoneUse]),
      talkingImage: PermissionItem(
          prompt: "需要访问你拍照权限",
          permissions: Platform.isAndroid
              ? [
                  AndroidPermission.writeExternalStorage,
                  AndroidPermission.readExternalStorage,
                  AndroidPermission.camera
                ]
              : [
                  IOSPermission.photoLibraryUse,
                  IOSPermission.cameraUse,
                ]),
      talkingVideo: PermissionItem(
          prompt: "拍照视频权限",
          permissions: Platform.isAndroid
              ? [
                  AndroidPermission.writeExternalStorage,
                  AndroidPermission.readExternalStorage,
                  AndroidPermission.camera,
                  AndroidPermission.recordAudio
                ]
              : [IOSPermission.photoLibraryUse, IOSPermission.cameraUse, IOSPermission.microphoneUse]),
    );
  }
}
