import 'package:eyflutter_core/eyflutter_core.dart';
import 'package:eyflutter_uikit/eyflutter_uikit.dart';
import 'package:eyflutter_uikit_example/configuration/picker_permission_config.dart';
import 'package:eyflutter_uikit_example/convex_bottom_bar_page.dart';
import 'package:eyflutter_uikit_example/drop_page.dart';
import 'package:eyflutter_uikit_example/export_sudoku_dialog.dart';
import 'package:eyflutter_uikit_example/flow_page.dart';
import 'package:eyflutter_uikit_example/image_page.dart';
import 'package:eyflutter_uikit_example/input_number_page.dart';
import 'package:eyflutter_uikit_example/my_tab_page.dart';
import 'package:eyflutter_uikit_example/pop_page.dart';
import 'package:eyflutter_uikit_example/rich_text_page.dart';
import 'package:eyflutter_uikit_example/setting_bar_page.dart';
import 'package:eyflutter_uikit_example/single_text_edit_dialog.dart';
import 'package:flutter/material.dart';

class Home extends StatefulWidget {
  const Home({Key? key}) : super(key: key);

  @override
  _HomeState createState() => _HomeState();
}

class _HomeState extends LifecycleState<Home> {
  @override
  String get viewName => "home";

  @override
  Widget build(BuildContext context) {
    super.build(context);
    return Scaffold(
      appBar: AppBar(
        title: const Text('eyflutter demo'),
      ),
      resizeToAvoidBottomInset: false,
      body: ConstListView(
        itemCount: 20,
        itemExtent: 50,
        buttons: [
          ConstButton(
            text: "Flow Widget",
            onLongPress: () {
              ConstNavigator.go(context: context, target: const FlowPage());
            },
          ),
          ConstButton(
            text: "RichText Widget",
            onLongPress: () {
              ConstNavigator.go(context: context, target: const RichTextPage());
            },
          ),
          ConstButton(
            text: "Setting Bar Widget",
            onLongPress: () {
              ConstNavigator.go(context: context, target: const SettingBarPage());
            },
          ),
          ConstButton(
            text: "radio group widget",
            onLongPress: () {
              ExportSudokuDialog.instance.show(context: context);
            },
          ),
          ConstButton(
            text: "input number计数器",
            onLongPress: () {
              ConstNavigator.go(context: context, target: const InputNumberPage());
            },
          ),
          ConstButton(
            text: "drop widget",
            onLongPress: () {
              ConstNavigator.go(context: context, target: const DropPage());
            },
          ),
          ConstButton(
            text: "convex bottom bar",
            onLongPress: () {
              ConstNavigator.go(context: context, target: const ConvexBottomBarPage());
            },
          ),
          ConstButton(
            text: "tab page",
            onLongPress: () {
              ConstNavigator.go(context: context, target: const MyTabPage());
            },
          ),
          ConstButton(
            text: "edit dialog",
            onLongPress: () {
              SingleTextEditDialog.instance.show(
                context: context,
                title: "新建诗单",
                hintText: "请输入诗单",
                complete: () {},
              );
            },
          ),
          ConstButton(
            text: "pop page",
            onLongPress: () {
              ConstNavigator.go(context: context, target: const PopPage());
            },
          ),
          ConstButton(
            text: "message dialog",
            onLongPress: () {
              Dialogs.instance.showDialog(
                context,
                title: "标题",
                message: "消息内容",
                alignment: Alignment.center,
                backgroundColor: const Color(0xffFCF7EB),
                borderRadius: const BorderRadius.all(Radius.circular(16)),
                buttonArgs: [
                  ButtonArgs(
                    text: "取消",
                    action: "cancel",
                    color: const Color(0xe63B372C),
                    backgroundColor: const Color(0xffF1EDE1),
                    margin: const EdgeInsets.only(left: 20, right: 8, bottom: 20),
                    borderRadius: const BorderRadius.all(Radius.circular(20)),
                  ),
                  ButtonArgs(
                    text: "确定",
                    action: "confirm",
                    color: const Color(0xffF2EEE3),
                    backgroundColor: const Color(0xff5C6047),
                    margin: const EdgeInsets.only(left: 8, right: 20, bottom: 20),
                    borderRadius: const BorderRadius.all(Radius.circular(20)),
                  ),
                ],
              );
            },
          ),
          ConstButton(
            text: "custom dialog",
            onLongPress: () {
              Dialogs.instance.showDialog(context,
                  title: "认证",
                  contentView: const _CertificationView(),
                  buttonArgs: [
                    ButtonArgs(
                      text: "下一步",
                      action: "nextStep",
                      fontWeight: FontWeight.w600,
                    )
                  ],
                  buttonPressed: (ButtonArgs buttonArgs) {});
            },
          ),
          ConstButton(
            text: "toast",
            onLongPress: () {
              ToastUtils.instance.show("message");
            },
          ),
          ConstButton(
            text: "图片选择器",
            onLongPress: () {
              PickersManager.instance.showPickers(
                arguments: PickersArguments(
                  maxCount: 1,
                  clipPhoto: true,
                  clipCircle: true,
                  spanCount: 4,
                ),
                langArguments: PickersLangs(
                    loading: "加载中",
                    preview: "预览",
                    reTake: "重拍",
                    send: "发送",
                    cancle: "取消",
                    setting: "设置",
                    photo: "照片",
                    video: "视频",
                    camera: "摄像头",
                    cropTitle: "裁剪",
                    chooseLimit: ChooseLimit(
                      message: "最多可选择1张",
                      confirm: "确认",
                    )),
                permission: PickerPermissionConfig.getPermission(),
                selectorCall: (List<PickerModel> models) {
                  Logger.instance.info(models);
                },
              );
            },
          ),
          ConstButton(
            text: "image page",
            onLongPress: () {
              ConstNavigator.go(context: context, target: const ImagePage());
            },
          ),
        ],
      ),
    );
  }

  @override
  void onKeyboardChanged(bool visibility) {
    super.onKeyboardChanged(visibility);
  }
}

class _CertificationModel extends CusChangeNotifier {
  String realNameTag = "realName";
  String idTag = "idNo";
  OnFormFieldController? fieldController;
}

class _CertificationView extends StatefulWidget {
  const _CertificationView({Key? key}) : super(key: key);

  @override
  _CertificationViewState createState() => _CertificationViewState();
}

class _CertificationViewState extends State<_CertificationView> {
  _CertificationModel model = _CertificationModel();

  @override
  Widget build(BuildContext context) {
    return buildForm(context);
  }

  Widget buildForm(BuildContext context) {
    return TextFields(
      items: [
        TextFieldItem(
          tag: model.realNameTag,
          hintText: "请输入姓名",
          hintStyle: const TextStyle(color: Color(0x4d3B372C), fontSize: 14),
          labelText: "姓名",
          labelStyle: const TextStyle(color: Color(0xe63B372C), fontSize: 14),
          border: const Border(bottom: BorderSide(color: Color(0x1a3B372C), width: 0.5)),
          validator: (value) {
            if (value.isEmptyString) {
              return "请输入姓名";
            }
            return null;
          },
        ),
        TextFieldItem(
          tag: model.idTag,
          hintText: "请输入身份证号",
          hintStyle: const TextStyle(color: Color(0x4d3B372C), fontSize: 14),
          labelText: "身份证",
          labelStyle: const TextStyle(color: Color(0xe63B372C), fontSize: 14),
          border: const Border(bottom: BorderSide(color: Color(0x1a3B372C), width: 0.5)),
          validator: (value) {
            if (value.isEmptyString) {
              return "请输入身份证号";
            }
            return null;
          },
        ),
      ],
      controllerCall: (controller) {
        model.fieldController = controller;
      },
    );
  }
}
