import 'dart:math';

import 'package:eyflutter_uikit/eyflutter_uikit.dart';
import 'package:flutter/material.dart';

class MyTabTest extends StatefulWidget {
  const MyTabTest({Key? key}) : super(key: key);

  @override
  _MyTabTestState createState() => _MyTabTestState();
}

class _MyTabTestState extends State<MyTabTest> with SingleTickerProviderStateMixin {
  late TabController tabController;

  @override
  void initState() {
    super.initState();
    tabController = TabController(length: 2, vsync: this);
  }

  @override
  Widget build(BuildContext context) {
    MediaUtils.instance.setContext(context);
    return Scaffold(
        appBar: AppBar(title: const Text("标题")),
        body: CustomScrollView(
          slivers: <Widget>[
            _buildStickyBar(),
            _buildList(),
          ],
        ));
  }

  Widget _buildStickyBar() {
    return SliverPersistentHeader(
      pinned: true, //是否固定在顶部
      delegate: SliverAppBarDelegate(
          minHeight: 0,
          maxHeight: MediaUtils.instance.screenHeight,
          child: const ScrollVerticalView(
            child: Text(
                "苏州海关副关长 程维勇：前10个月，苏州高新技术产品出口6385.1亿元，同比增长8.4%。从智能小家电，到航空航天器材，有近千种产品，一批苏州企业从“制造”到“智造”走向全球。据海关统计，今年前10个月，我国机电产品出口11.25万亿元，同比增长9.6%；其中，电动载人汽车、锂电池、太阳能电池等出口分别增长116.2%、87.1%、78.6%。同期，劳动密集型产品出口3.54万亿元，增长11.2%；其中箱包、鞋、玩具等出口分别增长34.6%、27.2%和13.1%。",
                style: TextStyle(fontSize: 18)),
          )),
    );
  }

  Widget _buildList() {
    return SliverList(
        delegate: SliverChildBuilderDelegate(
      (context, index) {
        return Container(
          height: 50,
          color: index % 2 == 0 ? Colors.white : Colors.black12,
          width: double.infinity,
          alignment: Alignment.center,
          child: Text("我是第$index个item"),
        );
      },
      childCount: 30,
    ));
  }
}

class SliverAppBarDelegate extends SliverPersistentHeaderDelegate {
  SliverAppBarDelegate({
    required this.minHeight,
    required this.maxHeight,
    required this.child,
  });

  final double minHeight;
  final double maxHeight;
  final Widget child;

  @override
  double get minExtent => minHeight;

  @override
  double get maxExtent => max(maxHeight, minHeight);

  @override
  Widget build(BuildContext context, double shrinkOffset, bool overlapsContent) {
    return SizedBox.expand(child: child);
  }

  @override
  bool shouldRebuild(SliverAppBarDelegate oldDelegate) {
    return maxHeight != oldDelegate.maxHeight || minHeight != oldDelegate.minHeight || child != oldDelegate.child;
  }
}
