import 'package:eyflutter_core/eyflutter_core.dart';
import 'package:eyflutter_uikit/uikit/bars/action_bar.dart';
import 'package:eyflutter_uikit/uikit/state/base_form_state.dart';
import 'package:eyflutter_uikit/uikit/state/lifecycle_state.dart';
import 'package:eyflutter_uikit/uikit/state/state_utils.dart';
import 'package:flutter/material.dart';

abstract class BaseState<T extends StatefulWidget> extends LifecycleState<T> with OnLangChangeState {
  Locale? _locale;

  /// 是否预留顶部安全区域
  bool get topSafeArea => false;

  /// 是否预留底部安全区域
  bool get bottomSafeArea => false;

  /// 页面背景颜色
  Color? get backgroundColor => Color(0xFFF4F4F4);

  /// 解决键盘是否顶起页面
  /// 指定是否应在出现键盘时调整主体大小
  bool get resizeToAvoidBottomInset => true;

  @override
  void onCreate(BuildContext context, String routeName, Map<String, dynamic> arguments) {
    _locale = Localizations.localeOf(context);
    LangManager.instance.addChangeState(this.hashCode, this);
    var stateListener = StateUtils.instance.getStateListener();
    stateListener?.onBuildCall(context: context, viewName: viewName);
  }

  @override
  void dispatchLangState(Locale locale) {
    if (mounted) {
      setState(() {
        _locale = locale;
      });
    }
  }

  @override
  void onResume(String routeName, Map<String, dynamic> arguments) {
    var stateListener = StateUtils.instance.getStateListener();
    stateListener?.onResume(viewName, routeName, arguments);
  }

  @override
  void onPause(String routeName, Map<String, dynamic> arguments) {
    var stateListener = StateUtils.instance.getStateListener();
    stateListener?.onPause(viewName, routeName, arguments);
  }

  @override
  void onDestroy(String routeName, Map<String, dynamic> arguments) {
    LangManager.instance.removeChangeState(this.hashCode);
  }

  /// 构建顶部导航条
  ActionBar? onActionBar() {
    return null;
  }

  OnBackPressed? onBackClick() {
    return null;
  }

  ///在@override#build中调用
  Widget overrideLocalizations({required BuildContext context, required Widget child}) {
    return SafeArea(
      child: WillPopScope(
        child: Scaffold(
          backgroundColor: backgroundColor,
          appBar: onActionBar(),
          resizeToAvoidBottomInset: resizeToAvoidBottomInset,
          body: Localizations.override(
            context: context,
            locale: _locale,
            child: GestureDetector(
              child: child,
              onTap: () => SoftUtils.hideSoft(context),
            ),
          ),
        ),
        onWillPop: () {
          var backClick = onBackClick();
          if (backClick != null) {
            return backClick();
          }
          return Future.value(true);
        },
      ),
      top: topSafeArea,
      bottom: bottomSafeArea,
    );
  }
}
