import 'package:eyflutter_core/eyflutter_core.dart';
import 'package:eyflutter_uikit/utils/media_utils.dart';
import 'package:flutter/material.dart';
import 'package:oktoast/oktoast.dart';

enum ToastGravity {
  TOP,
  CENTER,
  BOTTOM,
}

enum ToastDuration {
  LONG,
  SHORT,
}

class ToastUtils {
  factory ToastUtils() => _getInstance();

  static ToastUtils get instance => _getInstance();
  static ToastUtils? _instance;

  ToastUtils._internal();

  static ToastUtils _getInstance() {
    return _instance ??= new ToastUtils._internal();
  }

  /// 显示toast提示
  /// [msg] 提示内容
  /// [gravity] 显示位置(即对齐方式)
  /// [duration] 显示
  void show(String msg, {ToastGravity gravity = ToastGravity.BOTTOM, ToastDuration duration = ToastDuration.LONG}) {
    showToastWidget(
      Row(
        mainAxisSize: MainAxisSize.min,
        children: [
          Container(
            padding: EdgeInsets.only(left: 16, top: 10, right: 16, bottom: 10),
            margin: EdgeInsets.only(left: 20, right: 20, bottom: gravity == ToastGravity.BOTTOM ? 60 : 0),
            decoration: BoxDecoration(
              color: Color(0xe63B372C),
              borderRadius: BorderRadius.all(Radius.circular(8)),
            ),
            constraints: BoxConstraints(
              minHeight: 38,
              maxWidth: MediaUtils.instance.screenWidth - 40,
            ),
            child: Text(
              msg,
              style: TextStyle(color: Color(0xffFCF7EB), fontSize: 12),
              softWrap: true,
              maxLines: 10,
              textAlign: TextAlign.justify,
            ),
          ),
        ],
      ),
      position: gravity == ToastGravity.BOTTOM ? ToastPosition.bottom : ToastPosition.center,
      duration: duration == ToastDuration.LONG ? Duration(milliseconds: 1500) : Duration(milliseconds: 1000),
      handleTouch: false,
    );
  }

  /// 显示组件toast
  void showWidget({required Widget child, ToastPosition? position, VoidCallback? onDismiss, bool? handleTouch}) {
    showToastWidget(child, position: position, onDismiss: onDismiss, handleTouch: handleTouch);
  }

  /// 显示原生消息
  void showNative(String msg) {
    CloudChannelManager.instance.send("aa94dd6839b29726", arguments: {"msg": msg, "gravity": "BOTTOM"});
  }
}
