import 'package:eyflutter_core/eyflutter_core.dart';
import 'package:eyflutter_uikit/eyflutter_uikit.dart';
import 'package:flutter/material.dart';

class CardWidget extends StatelessWidget {
  /// 组件外边距
  final EdgeInsetsGeometry? margin;

  /// 组件内边距
  final EdgeInsetsGeometry? padding;

  /// 子组件
  final Widget child;

  /// 背景
  final Color? backgroundColor;

  /// urlOrAlias
  final String? backgroundImage;

  /// 事件回调
  final VoidCallback? onPressed;

  /// 组件圆角
  final BorderRadiusGeometry? borderRadius;

  /// 组件边框
  final Border? border;

  ///  组件宽度
  final double? width;

  /// 组件高度
  final double? height;

  const CardWidget({
    Key? key,
    this.margin,
    required this.child,
    this.backgroundColor,
    this.backgroundImage,
    this.onPressed,
    this.borderRadius,
    this.border,
    this.padding,
    this.width,
    this.height,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Card(
      shape: RoundedRectangleBorder(borderRadius: borderRadius ?? const BorderRadius.all(Radius.circular(10))),
      shadowColor: const Color(0xffEEECE4),
      elevation: 3,
      clipBehavior: Clip.none,
      margin: margin,
      child: Container(
        width: width,
        height: height,
        decoration: BoxDecoration(
          image: getBoxDecoration(backgroundImage),
          borderRadius: borderRadius ?? const BorderRadius.all(Radius.circular(10)),
          border: border,
        ),
        child: TextButton(
          onPressed: onPressed,
          child: child,
          style: ButtonStyle(
            backgroundColor: MaterialStateProperty.all(backgroundColor),
            shape: MaterialStateProperty.all(
                RoundedRectangleBorder(borderRadius: borderRadius ?? const BorderRadius.all(Radius.circular(10)))),
            padding: MaterialStateProperty.all(padding ?? EdgeInsets.zero),
            visualDensity: VisualDensity.compact,
            minimumSize: MaterialStateProperty.all(Size(width ?? 0, height ?? 0)),
          ),
        ),
      ),
      color: backgroundColor,
    );
  }

  DecorationImage? getBoxDecoration(String? urlOrAlias) {
    if (urlOrAlias.isEmptyString) {
      return null;
    }
    var imageProvider = getImageProvider(urlOrAlias);
    if (imageProvider == null) {
      return null;
    }
    return DecorationImage(
      image: imageProvider,
      fit: BoxFit.cover,
    );
  }

  ImageProvider? getImageProvider(String? urlOrAlias) {
    if (urlOrAlias.isEmptyString) {
      return null;
    }
    if (urlOrAlias.isUrl) {
      return CachedImageProvider.imageProvider(url: urlOrAlias!);
    } else if (urlOrAlias!.startsWith("packages/")) {
      return AssetImageProvider.render(urlOrAlias, isProjectImage: true);
    }
    return null;
  }
}
