import 'package:flutter/material.dart';

class InkButton extends StatelessWidget {
  /// 子组件
  final Widget child;

  /// 组件宽度
  final double width;

  /// 组件高度
  final double height;

  /// 边框圆角
  final BorderRadiusGeometry? borderRadius;

  /// 内边距
  final EdgeInsetsGeometry? padding;

  /// 外边距
  final EdgeInsetsGeometry? margin;

  final EdgeInsetsGeometry markMargin;

  /// 背景
  final Color? backgroundColor;

  /// 点击事件
  final Function()? onPressed;

  /// 定位组件
  final Widget? position;

  /// 子组件对齐方式
  final AlignmentGeometry? alignment;

  const InkButton({
    Key? key,
    required this.child,
    required this.width,
    required this.height,
    this.borderRadius,
    this.padding,
    this.margin,
    this.markMargin = EdgeInsets.zero,
    this.backgroundColor,
    this.onPressed,
    this.position,
    this.alignment,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      height: height,
      padding: padding,
      margin: margin,
      alignment: alignment,
      decoration: BoxDecoration(
        color: backgroundColor,
        borderRadius: borderRadius,
      ),
      child: Stack(
        children: buildChildList(),
      ),
    );
  }

  List<Widget> buildChildList() {
    List<Widget> childList = [
      Positioned(
        child: child,
        left: 0,
        top: 0,
        right: 0,
        bottom: 0,
      ),
      Padding(
        padding: markMargin,
        child: TextButton(
          child: SizedBox(
            width: width,
            height: height,
          ),
          onPressed: onPressed,
          style: ButtonStyle(
            shape: MaterialStateProperty.all(RoundedRectangleBorder(borderRadius: borderRadius ?? BorderRadius.zero)),
            padding: MaterialStateProperty.all(EdgeInsets.zero),
          ),
        ),
      )
    ];
    if (position != null) {
      childList.add(position!);
    }
    return childList;
  }
}
