import 'package:flutter/material.dart';

mixin PrimaryButtonController {
  void updateStatus(bool enable);
}

class PrimaryButton extends StatefulWidget {
  /// 按钮文本
  final String text;

  /// 文本大小
  final double fontSize;

  /// 文本颜色
  final Color textColor;

  /// 文本权重
  final FontWeight? fontWeight;

  /// 禁用文本颜色
  final Color disableTextColor;

  /// 事件回调
  final VoidCallback onPressed;

  /// 组件宽度
  final double? width;

  /// 组件高度
  final double? height;

  /// 背景颜色
  final Color backgroundColor;

  /// 禁用背景颜色
  final Color disableBackgroundColor;

  /// 按钮按下时颜色
  final Color? overlayColor;

  /// 组件圆角
  final BorderRadiusGeometry borderRadius;

  /// 子组件,设置该值后文本相关属性失效
  final Widget? child;

  /// 边框颜色
  final Color borderColor;

  /// 边框宽度
  final double borderWidth;

  /// 按钮内边距
  final EdgeInsetsGeometry padding;

  /// 按钮外边距
  final EdgeInsetsGeometry margin;

  /// 是否显示组件
  final bool visible;

  /// 按钮是否启用
  final bool enable;

  final Function(PrimaryButtonController controller)? buildCall;

  final AlignmentGeometry? alignment;

  const PrimaryButton({
    Key? key,
    this.text = "",
    required this.onPressed,
    this.fontSize = 14,
    this.textColor = const Color(0xff222222),
    this.fontWeight,
    this.disableTextColor = const Color(0x80222222),
    this.width,
    this.height = 38,
    this.backgroundColor = const Color(0xffEEEBD7),
    this.disableBackgroundColor = const Color(0xffEEEBD7),
    this.overlayColor,
    this.borderRadius = const BorderRadius.all(Radius.circular(30)),
    this.child,
    this.borderColor = const Color(0xffEEEBD7),
    this.borderWidth = 1,
    this.margin = EdgeInsets.zero,
    this.visible = true,
    this.padding = EdgeInsets.zero,
    this.enable = true,
    this.buildCall,
    this.alignment,
  }) : super(key: key);

  @override
  _PrimaryButtonState createState() => _PrimaryButtonState();
}

class _PrimaryButtonState extends State<PrimaryButton> with PrimaryButtonController {
  bool _enable = true;

  @override
  void initState() {
    super.initState();
    _enable = widget.enable;
    if (widget.buildCall != null) {
      widget.buildCall!(this);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Visibility(
      child: Container(
        width: widget.width,
        height: widget.height,
        padding: widget.padding,
        margin: widget.margin,
        alignment: widget.alignment,
        decoration: BoxDecoration(
          color: _enable ? widget.backgroundColor : widget.disableBackgroundColor,
          border: Border.all(color: widget.borderColor, width: widget.borderWidth),
          borderRadius: widget.borderRadius,
        ),
        constraints: BoxConstraints(
          minWidth: widget.width ?? 80,
        ),
        child: TextButton(
          onPressed: _enable ? widget.onPressed : null,
          child: widget.child ??
              Text(
                widget.text,
                style: TextStyle(
                  color: _enable ? widget.textColor : widget.disableTextColor,
                  fontSize: widget.fontSize,
                  fontWeight: widget.fontWeight,
                ),
              ),
          style: ButtonStyle(
            backgroundColor:
                MaterialStateProperty.all(_enable ? widget.backgroundColor : widget.disableBackgroundColor),
            overlayColor: MaterialStateProperty.all(widget.overlayColor),
            shape: MaterialStateProperty.all(RoundedRectangleBorder(borderRadius: widget.borderRadius)),
            padding: MaterialStateProperty.all(EdgeInsets.zero),
            // visualDensity: VisualDensity.compact,
            minimumSize: MaterialStateProperty.all(Size(widget.width ?? 0, widget.height ?? 0)),
          ),
        ),
      ),
      visible: widget.visible,
    );
  }

  @override
  void updateStatus(bool enable) {
    setState(() {
      _enable = enable;
    });
  }
}
