import 'dart:async';

import 'package:eyflutter_core/eyflutter_core.dart';
import 'package:eyflutter_uikit/uikit/state/state_utils.dart';
import 'package:flutter/material.dart';

enum TimeCountFormat {
  /// 00:00:00
  HMS,

  /// 00:00
  MS
}

class TimeCountModel extends ProviderModel {
  int _time = 0;
  Timer? _timer;
  String timeText = "";

  /// 获取统计时间
  int get countTime => _time;

  void _timing(TimeCountFormat format, int maxTime) {
    _timer = Timer.periodic(Duration(seconds: 1), (timer) {
      _time++;
      int hour = _time ~/ 3600;
      int minutes = (_time - hour * 3600) ~/ 60;
      int seconds = _time - hour * 3600 - minutes * 60;
      if (format == TimeCountFormat.HMS) {
        timeText =
            "${hour >= 10 ? hour : "0$hour"}:${minutes >= 10 ? minutes : "0$minutes"}:${seconds >= 10 ? seconds : "0$seconds"}";
      } else if (format == TimeCountFormat.MS) {
        timeText = "${minutes >= 10 ? minutes : "0$minutes"}:${seconds >= 10 ? seconds : "0$seconds"}";
      }
      if (maxTime == 0 || _time * 1000 < maxTime) {
        notifierLazy();
      }
    });
  }

  /// 开始计时
  /// [format] 显示时间格式
  /// [maxTime] 最大时间(单位毫秒)
  void start({TimeCountFormat format = TimeCountFormat.HMS, int maxTime = 0}) {
    cancel();
    _timing(format, maxTime);
    notifierLazy();
  }

  /// 重置计时
  /// [format] 显示时间格式
  /// [maxTime] 最大时间(单位毫秒)
  void reset({TimeCountFormat format = TimeCountFormat.HMS, int maxTime = 0}) {
    _time = 0;
    start(format: format, maxTime: maxTime);
  }

  /// 取消计时统计
  void cancel() {
    if (_timer?.isActive ?? false) {
      _timer?.cancel();
    }
  }
}

/// 计时统计
class TimeCount extends StatefulWidget {
  /// 计时统计模型
  final TimeCountModel countModel;

  //文本颜色
  final Color textColor;

  //文本大小
  final double textSize;

  const TimeCount({Key? key, required this.countModel, required this.textColor, required this.textSize})
      : super(key: key);

  @override
  _TimeState createState() => _TimeState();
}

class _TimeState extends State<TimeCount> {
  @override
  Widget build(BuildContext context) {
    return StateUtils.instance.subscribeNotifierWidget<TimeCountModel>(widget.countModel, (context, model) {
      return Text(
        model.timeText,
        style: TextStyle(color: widget.textColor, fontSize: widget.textSize),
      );
    });
  }

  @override
  void dispose() {
    widget.countModel.cancel();
    super.dispose();
  }
}
